(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     27432,        728]*)
(*NotebookOutlinePosition[     28077,        750]*)
(*  CellTagsIndexPosition[     28033,        746]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Methoden der Bioinformatik",
    FontSize->24,
    FontWeight->"Bold"],
  StyleBox[" \n",
    FontSize->12],
  StyleBox["Eine Einf\[UDoubleDot]hrung",
    FontSize->18,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12],
  StyleBox["Marc-Thorsten H\[UDoubleDot]tt und Manuel Dehnert",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12],
  StyleBox["Springer-Verlag 2006 (ISBN 3-540-25687-3)",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12]
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurs: ",
  "Viterbi-Algorithmus"
}], "Subtitle",
  Background->RGBColor[0.0901961, 0.462745, 0.396078]],

Cell[TextData[{
  "In dem vorangegangenen Abschnitt wurde der Viterbi-Algorithmus eingef\
\[UDoubleDot]hrt und am Beispiel eines Hidden-Markov-Modells f\[UDoubleDot]r \
ein gelegentlich unehrliches Kasino erl\[ADoubleDot]utert. Dieses Modell soll \
uns nun auch als Beispiel f\[UDoubleDot]r die Implementierung des \
Viterbi-Algorithmus in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " dienen. Im ersten Schritt wird das Modell durch den Zustandsraum des HMM, \
den Zustandsraum der beobachteten Sequenz, die \
\[CapitalUDoubleDot]bergangswahrscheinlichkeiten und die \
Emissionswahrscheinlichkeiten spezifiziert.\n\nDer Zustandsraum des HMM wird \
festgelegt als"
}], "Text",
  FontSize->13],

Cell[BoxData[
    \(\(state = {"\<0\>", "\<F\>", "\<U\>"};\)\)], "Input"],

Cell["\<\
wobei \"0\" f\[UDoubleDot]r den Anfangszustand steht, \"F\" f\[UDoubleDot]r \
den fairen und \"U\" f\[UDoubleDot]r den unfairen W\[UDoubleDot]rfel. Der \
Zustandsraum der Sequenz ist der eines gew\[ODoubleDot]hnlichen \
W\[UDoubleDot]rfels.\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(\(observation = {1, 2, 3, 4, 5, 6};\)\)], "Input"],

Cell["\<\
Die \[CapitalUDoubleDot]bergangswahrscheinlichkeiten zwischen den drei Zust\
\[ADoubleDot]nden \"0\", \"F\" und \"U\" werden in Form einer Funktion \
definiert. Die Argumente sind die Zust\[ADoubleDot]nde und der ausgegebene \
Funktionswert ist die zugeh\[ODoubleDot]rige \
\[CapitalUDoubleDot]bergangswahrscheinlichkeit.\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(\(transition[z1_, z2_] := 
        Switch[{z1, z2}, \[IndentingNewLine]{"\<F\>", "\<F\>"}, 
          0.95, \[IndentingNewLine]{"\<F\>", "\<U\>"}, 
          0.05, \[IndentingNewLine]{"\<U\>", "\<U\>"}, 
          0.90, \[IndentingNewLine]{"\<U\>", "\<F\>"}, 
          0.10, \[IndentingNewLine]{"\<0\>", "\<U\>"}, 
          0.5, \[IndentingNewLine]{"\<0\>", "\<F\>"}, 
          0.5, \[IndentingNewLine]{"\<0\>", "\<0\>"}, 
          0.0, \[IndentingNewLine]{"\<U\>", "\<0\>"}, 
          0.0, \[IndentingNewLine]{"\<F\>", "\<0\>"}, 0.0];\)\)], "Input"],

Cell["\<\
In gleicher Weise werden auch die Emissionswahrscheinlichkeiten festgelegt.\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(\(emission[z1_, z2_] := 
        Switch[z1, \[IndentingNewLine]"\<F\>", 
          N[1/6], \[IndentingNewLine]"\<U\>", 
          If[z2 \[Equal] 6, 0.5, 0.1], \[IndentingNewLine]"\<0\>", 
          0];\)\)], "Input"],

Cell[TextData[{
  "Dabei ist ",
  StyleBox["z1",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " erneut ein Symbol aus dem HMM-Zustandsraum ",
  StyleBox["state",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ", die Gr\[ODoubleDot]\[SZ]e ",
  StyleBox["z2",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " bezeichnet jetzt jedoch ein Symbol aus dem Zustandsraum ",
  StyleBox["observation",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " der beobachteten Sequenz. Wir wollen nun die von uns definierten \
Parameter des Modells stichprobenartig \[UDoubleDot]berpr\[UDoubleDot]fen und \
dabei die Funktionsweise der Implementierung verdeutlichen. Die \
Wahrscheinlichkeit, mit einem fairen W\[UDoubleDot]rfel eine 3 zu w\
\[UDoubleDot]rfeln, ist demnach gegeben durch"
}], "Text",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(emission["\<F\>", 3]\)], "Input"],

Cell[BoxData[
    \(0.16666666666666666`\)], "Output"]
}, Open  ]],

Cell["\<\
Die Wahrscheinlichkeit, von einem fairen W\[UDoubleDot]rfel im \
n\[ADoubleDot]chsten Schritt zu einem unfairen W\[UDoubleDot]rfel \
\[UDoubleDot]berzugehen, ist\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(transition["\<F\>", "\<U\>"]\)], "Input"],

Cell[BoxData[
    \(0.05`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Als N\[ADoubleDot]chstes ben\[ODoubleDot]tigen wir eine Beispielsequenz, \
auf die der Viterbi-Algorithmus angewendet werden kann. F\[UDoubleDot]r \
dieses einf\[UDoubleDot]hrende Beispiel erzeugen wir drei Teilsequenzen mit \
unterschiedlichen Eigenschaften. Die erste und die dritte Teilsequenz sind \
Realisierungen eines fairen W\[UDoubleDot]rfels, d.h. ",
  Cell[BoxData[
      \(TraditionalForm\`p\_Fi\)]],
  " = 1/6 \[ForAll] i \[Element] \[CapitalSigma]. Die zweite Teilsequenz ist \
eine Realisierung eines unfairen W\[UDoubleDot]rfels mit den \
Wahrscheinlichkeiten ",
  Cell[BoxData[
      \(TraditionalForm\`p\_U6\)]],
  " = 1/2 und ",
  Cell[BoxData[
      \(TraditionalForm\`p\_Ui\)]],
  " = 1/ 10, i = 1, . . . , 5."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(SeedRandom[2]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(seq0a = Table[Random[Integer, {1, 6}], {50}]\)], "Input"],

Cell[BoxData[
    \({5, 5, 3, 6, 1, 4, 4, 5, 3, 3, 5, 5, 6, 6, 1, 5, 1, 1, 6, 1, 2, 5, 3, 
      3, 1, 1, 2, 3, 3, 5, 2, 6, 2, 1, 4, 2, 5, 6, 6, 6, 5, 4, 4, 3, 5, 6, 2, 
      1, 3, 6}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(seq0b = 
      Table[If[Random[] < 0.5, 6, Random[Integer, {1, 5}]], {20}]\)], "Input"],

Cell[BoxData[
    \({6, 2, 6, 6, 5, 6, 4, 6, 1, 1, 6, 6, 2, 5, 6, 3, 6, 6, 6, 
      4}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(seq0c = Table[Random[Integer, {1, 6}], {50}]\)], "Input"],

Cell[BoxData[
    \({6, 4, 2, 1, 3, 6, 2, 2, 2, 1, 2, 4, 4, 6, 5, 1, 1, 6, 2, 3, 4, 2, 4, 
      5, 1, 1, 1, 6, 4, 4, 2, 5, 1, 2, 2, 4, 5, 3, 5, 5, 4, 3, 4, 3, 2, 1, 2, 
      4, 1, 2}\)], "Output"]
}, Open  ]],

Cell["\<\
Durch das einfache Aneinanderh\[ADoubleDot]ngen der Teilsequenzen erh\
\[ADoubleDot]lt man eine Sequenz, die zwei unterschiedliche verborgene Zust\
\[ADoubleDot]nde aufweist.\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(seq = Join[seq0a, seq0b, seq0c];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(L = Length[seq]\)], "Input"],

Cell[BoxData[
    \(120\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die interne Zustandssequenz, die wir in diesem konstruierten Beispiel \
genau kennen, legen wir an dieser Stelle in der Variablen ",
  StyleBox["label",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " ab und werden sie am Ende des ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurses mit der vom Viterbi-Algorithmus bestimmten Sequenz der internen \
Zust\[ADoubleDot]nde vergleichen."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(label = 
        Flatten[{Table["\<F\>", {50}], Table["\<U\>", {20}], 
            Table["\<F\>", {50}]}];\)\)], "Input"],

Cell["Der Initialisierung der Viterbi-Variablen", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(vit[z1_, 0, x_] := If[z1 == "\<0\>", 1, 0]\)], "Input"],

Cell["\<\
folgt die Rekursion. Dabei wird die Viterbi-Variable f\[UDoubleDot]r jeden \
Zustand entlang der Sequenz bestimmt.\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(Do[Do[\({\(tmpList = 
                Table[vit[state[\([k]\)], i - 1, seq]*
                    transition[state[\([k]\)], state[\([j]\)]], {k, 1, 
                    Length[state]}];\), \[IndentingNewLine]\(vit[
                  state[\([j]\)], i, seq] = 
                emission[state[\([j]\)], seq[\([i]\)]]*
                  Max[tmpList];\), \[IndentingNewLine]pointer[j, 
                i] = \(Flatten[
                  Position[tmpList, 
                    Max[tmpList]]]\)[\([1]\)]};\), \[IndentingNewLine]{j, 1, 
          Length[state]}], \[IndentingNewLine]{i, 1, L}]\)], "Input"],

Cell[TextData[{
  "Man erkennt im Inneren der beiden ",
  StyleBox["Do",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Schleifen (eine f\[UDoubleDot]r alle HMM-Zust\[ADoubleDot]nde, eine f\
\[UDoubleDot]r den Index entlang der Sequenz) deutlich die Umsetzung von \
Gleichung (2.86). Dabei wird die Liste f\[UDoubleDot]r die Maximumsabfrage \
zuerst in der Variablen ",
  StyleBox["tmpList",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " abgelegt. Die Position des Maximums dient als Codierung f\[UDoubleDot]r \
die Zust\[ADoubleDot]nde \"0\", \"F\", \"U\" und wird in der Variablen ",
  StyleBox["pointer",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " gespeichert. Der Zustand \"0\" wird durch 1 codiert, \"F\" durch 2 und \
\"U\" durch 3. Diese Struktur sollte aufgrund unserer vorangegangenen \
Diskussionen sehr klar sein. Die drei Befehle in der geschweiften Klammer im \
Innern der ",
  StyleBox["Do",
    FontWeight->"Bold"],
  "-Schleife sind: (1) die Liste f\[UDoubleDot]r die Maximumsabfrage, (2) die \
Umsetzung von Gleichung (2.86) und (3) die Zeigerzuweisung. Mit dem Befehl\n\n\
",
  StyleBox["Table[vit[state[[k]],i,seq],{k,1,Length[state]}]\n",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "\n",
  "l\[ADoubleDot]sst sich die Viterbi-Variable der Zust\[ADoubleDot]nde 1 \
(\"0\"), 2 (\"F\"), und 3 (\"U\") f\[UDoubleDot]r den Sequenzindex ",
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " ausgeben. Einige Beispiele:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(i = 0;\)\), "\[IndentingNewLine]", 
    \(Table[vit[state[\([k]\)], i, seq], {k, 1, Length[state]}]\)}], "Input"],

Cell[BoxData[
    \({1, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(i = 1;\)\), "\n", 
    \(Table[
      vit[state[\([\)\(k\)\(]\)], i, seq], {k, 1, Length[state]}]\)}], "Input"],

Cell[BoxData[
    \({0, 0.08333333333333333`, 0.05`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(i = 2;\)\), "\[IndentingNewLine]", 
    \(Table[vit[state[\([k]\)], i, seq], {k, 1, Length[state]}]\)}], "Input"],

Cell[BoxData[
    \({0, 0.013194444444444443`, 0.0045000000000000005`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Wir gelangen nun zur Ter",
  "minierung. F\[UDoubleDot]r den Index ",
  StyleBox["i = L",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " erh\[ADoubleDot]lt man die Viterbi-Variablen f\[UDoubleDot]r das \
Sequenzende und den letzten Wert der Zeigervariablen."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(tmpList = 
      Table[vit[state[\([k]\)], L, seq], {k, 1, Length[state]}]\)], "Input"],

Cell[BoxData[
    \({0, 1.337477033909819`*^-95, 4.2236116860310083`*^-97}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pointerFinal = \(Flatten[
          Position[tmpList, Max[tmpList]]]\)[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die ",
  StyleBox["Do",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Schleife ist die direkte Umsetzung von Gleichung (2.90). Von dem Zustand \
aus, der zum Maximum der Viterbi-Variablen f\[UDoubleDot]hrt, wird nun mit \
Hilfe des Traceback-Verfahrens der wahrscheinlichste Pfad ermittelt und \
ausgegeben."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(pathX[L] = pointerFinal;\)\)], "Input"],

Cell[BoxData[
    \(Do[pathX[j - 1] = pointer[pathX[j], j], {j, L, 1, \(-1\)}]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(path = Table[pathX[j], {j, 1, L}]\)], "Input"],

Cell[BoxData[
    \({2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
      2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
      2, 2, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 
      2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
      2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
      2}\)], "Output"]
}, Open  ]],

Cell["\<\
Die Visualisierung des Ergebnisses erfolgt durch eine etwas aufwendige \
Funktion, an der man gut einige fortgeschrittene Formatierungsfragen vorf\
\[UDoubleDot]hren kann:\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(makeViterbiOutput[sequenz_, rowLength_] := 
      Module[{tmp1, tmp2, tmp3}, \[IndentingNewLine]tmp1 = 
          Length[Transpose[sequenz]]; \[IndentingNewLine]Do[
          tmp2[jj] = 
            TableForm[
              Transpose[
                Take[Transpose[sequenz], {jj, 
                    Min[tmp1, jj + rowLength - 1]}]], 
              TableSpacing \[Rule] 0.1, 
              TableHeadings -> {{"\<Daten: \>", "\<W\[UDoubleDot]rfel: \>", "\
\<Viterbi: \>"}, None}], \[IndentingNewLine]{jj, 1, tmp1, 
            rowLength}]; \[IndentingNewLine]tmp3 = 
          TableForm[Table[tmp2[jj], {jj, 1, tmp1, rowLength}]]]\)], "Input"],

Cell[TextData[{
  "Das erste Argument dieser Visualisierungsroutine ist eine dreiteilige \
Liste aus der Sequenz, der (bekannten) Abfolge interner Zust\[ADoubleDot]nde \
und der Variablen ",
  StyleBox["path",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ", die die gerade ermittelte Viterbi-Decodierung enth\[ADoubleDot]lt. Dabei \
werden die Bezeichnungen durch die Elemente des HMM-Zustandsraums ersetzt."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(res = {seq, label, 
          path /. {1 \[Rule] "\<0\>", 2 \[Rule] "\<F\>", 
              3 \[Rule] "\<U\>"}};\)\)], "Input"],

Cell[TextData[{
  "Das zweite Argument ist die Zeilenl\[ADoubleDot]nge, die zur Formatierung \
der Ausgabe verwendet wird. Neben der Formatierung besteht die Aufgabe dieser \
Routine nur darin, die entsprechende Zeilenbezeichnung \
hinzuzuf\[UDoubleDot]gen. Das Endergebnis dieses ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurses lautet damit:"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(makeViterbiOutput[res, 20]\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[GridBox[{
                  {"\<\"Daten: \"\>", "5", "5", "3", "6", "1", "4", "4", "5", 
                    "3", "3", "5", "5", "6", "6", "1", "5", "1", "1", "6", 
                    "1"},
                  {"\<\"W\[UDoubleDot]rfel: \"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>"},
                  {"\<\"Viterbi: \"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>"}
                  },
                RowSpacings->0.1,
                ColumnSpacings->0.1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              Function[ BoxForm`e$, 
                TableForm[ 
                BoxForm`e$, TableSpacing -> .10000000000000001, 
                  TableHeadings -> {{"Daten: ", "W\[UDoubleDot]rfel: ", 
                  "Viterbi: "}, None}]]]},
          {
            TagBox[GridBox[{
                  {"\<\"Daten: \"\>", "2", "5", "3", "3", "1", "1", "2", "3", 
                    "3", "5", "2", "6", "2", "1", "4", "2", "5", "6", "6", 
                    "6"},
                  {"\<\"W\[UDoubleDot]rfel: \"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>"},
                  {"\<\"Viterbi: \"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>"}
                  },
                RowSpacings->0.1,
                ColumnSpacings->0.1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              Function[ BoxForm`e$, 
                TableForm[ 
                BoxForm`e$, TableSpacing -> .10000000000000001, 
                  TableHeadings -> {{"Daten: ", "W\[UDoubleDot]rfel: ", 
                  "Viterbi: "}, None}]]]},
          {
            TagBox[GridBox[{
                  {"\<\"Daten: \"\>", "5", "4", "4", "3", "5", "6", "2", "1", 
                    "3", "6", "6", "2", "6", "6", "5", "6", "4", "6", "1", 
                    "1"},
                  {"\<\"W\[UDoubleDot]rfel: \"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>", \
"\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>", \
"\<\"U\"\>"},
                  {"\<\"Viterbi: \"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>", \
"\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>"}
                  },
                RowSpacings->0.1,
                ColumnSpacings->0.1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              Function[ BoxForm`e$, 
                TableForm[ 
                BoxForm`e$, TableSpacing -> .10000000000000001, 
                  TableHeadings -> {{"Daten: ", "W\[UDoubleDot]rfel: ", 
                  "Viterbi: "}, None}]]]},
          {
            TagBox[GridBox[{
                  {"\<\"Daten: \"\>", "6", "6", "2", "5", "6", "3", "6", "6", 
                    "6", "4", "6", "4", "2", "1", "3", "6", "2", "2", "2", 
                    "1"},
                  {"\<\"W\[UDoubleDot]rfel: \"\>", "\<\"U\"\>", "\<\"U\"\>", \
"\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>", \
"\<\"U\"\>", "\<\"U\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>"},
                  {"\<\"Viterbi: \"\>", "\<\"U\"\>", "\<\"U\"\>", \
"\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>", \
"\<\"U\"\>", "\<\"U\"\>", "\<\"U\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>"}
                  },
                RowSpacings->0.1,
                ColumnSpacings->0.1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              Function[ BoxForm`e$, 
                TableForm[ 
                BoxForm`e$, TableSpacing -> .10000000000000001, 
                  TableHeadings -> {{"Daten: ", "W\[UDoubleDot]rfel: ", 
                  "Viterbi: "}, None}]]]},
          {
            TagBox[GridBox[{
                  {"\<\"Daten: \"\>", "2", "4", "4", "6", "5", "1", "1", "6", 
                    "2", "3", "4", "2", "4", "5", "1", "1", "1", "6", "4", 
                    "4"},
                  {"\<\"W\[UDoubleDot]rfel: \"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>"},
                  {"\<\"Viterbi: \"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>"}
                  },
                RowSpacings->0.1,
                ColumnSpacings->0.1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              Function[ BoxForm`e$, 
                TableForm[ 
                BoxForm`e$, TableSpacing -> .10000000000000001, 
                  TableHeadings -> {{"Daten: ", "W\[UDoubleDot]rfel: ", 
                  "Viterbi: "}, None}]]]},
          {
            TagBox[GridBox[{
                  {"\<\"Daten: \"\>", "2", "5", "1", "2", "2", "4", "5", "3", 
                    "5", "5", "4", "3", "4", "3", "2", "1", "2", "4", "1", 
                    "2"},
                  {"\<\"W\[UDoubleDot]rfel: \"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>"},
                  {"\<\"Viterbi: \"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", \
"\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>", "\<\"F\"\>"}
                  },
                RowSpacings->0.1,
                ColumnSpacings->0.1,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              Function[ BoxForm`e$, 
                TableForm[ 
                BoxForm`e$, TableSpacing -> .10000000000000001, 
                  TableHeadings -> {{"Daten: ", "W\[UDoubleDot]rfel: ", 
                  "Viterbi: "}, None}]]]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        TableForm[ {{5, 5, 3, 6, 1, 4, 4, 5, 3, 3, 5, 5, 6, 6, 1, 5, 1, 1, 6, 
          1}, {"F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", 
          "F", "F", "F", "F", "F", "F", "F", "F"}, {"F", "F", "F", "F", "F", 
          "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", 
          "F", "F"}}, TableSpacing -> .10000000000000001, TableHeadings -> {{
          "Daten: ", "W\[UDoubleDot]rfel: ", "Viterbi: "}, None}], 
        TableForm[ {{2, 5, 3, 3, 1, 1, 2, 3, 3, 5, 2, 6, 2, 1, 4, 2, 5, 6, 6, 
          6}, {"F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", 
          "F", "F", "F", "F", "F", "F", "F", "F"}, {"F", "F", "F", "F", "F", 
          "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", 
          "F", "F"}}, TableSpacing -> .10000000000000001, TableHeadings -> {{
          "Daten: ", "W\[UDoubleDot]rfel: ", "Viterbi: "}, None}], 
        TableForm[ {{5, 4, 4, 3, 5, 6, 2, 1, 3, 6, 6, 2, 6, 6, 5, 6, 4, 6, 1, 
          1}, {"F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "U", "U", 
          "U", "U", "U", "U", "U", "U", "U", "U"}, {"F", "F", "F", "F", "F", 
          "F", "F", "F", "F", "U", "U", "U", "U", "U", "U", "U", "U", "U", 
          "U", "U"}}, TableSpacing -> .10000000000000001, TableHeadings -> {{
          "Daten: ", "W\[UDoubleDot]rfel: ", "Viterbi: "}, None}], 
        TableForm[ {{6, 6, 2, 5, 6, 3, 6, 6, 6, 4, 6, 4, 2, 1, 3, 6, 2, 2, 2, 
          1}, {"U", "U", "U", "U", "U", "U", "U", "U", "U", "U", "F", "F", 
          "F", "F", "F", "F", "F", "F", "F", "F"}, {"U", "U", "U", "U", "U", 
          "U", "U", "U", "U", "U", "U", "F", "F", "F", "F", "F", "F", "F", 
          "F", "F"}}, TableSpacing -> .10000000000000001, TableHeadings -> {{
          "Daten: ", "W\[UDoubleDot]rfel: ", "Viterbi: "}, None}], 
        TableForm[ {{2, 4, 4, 6, 5, 1, 1, 6, 2, 3, 4, 2, 4, 5, 1, 1, 1, 6, 4, 
          4}, {"F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", 
          "F", "F", "F", "F", "F", "F", "F", "F"}, {"F", "F", "F", "F", "F", 
          "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", 
          "F", "F"}}, TableSpacing -> .10000000000000001, TableHeadings -> {{
          "Daten: ", "W\[UDoubleDot]rfel: ", "Viterbi: "}, None}], 
        TableForm[ {{2, 5, 1, 2, 2, 4, 5, 3, 5, 5, 4, 3, 4, 3, 2, 1, 2, 4, 1, 
          2}, {"F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", 
          "F", "F", "F", "F", "F", "F", "F", "F"}, {"F", "F", "F", "F", "F", 
          "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", "F", 
          "F", "F"}}, TableSpacing -> .10000000000000001, TableHeadings -> {{
          "Daten: ", "W\[UDoubleDot]rfel: ", "Viterbi: "}, 
          None}]}]]], "Output"]
}, Open  ]],

Cell["\<\
Offensichtlich identifiziert der Viterbi-Algorithmus unsere zwischenzeitliche \
Verwendung des unfairen W\[UDoubleDot]rfels fast elementgenau.\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowSize->{507, 651},
WindowMargins->{{Automatic, 57}, {Automatic, 53}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 553, 21, 115, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2332, 76, 177, 6, 97, "Subtitle"],
Cell[2512, 84, 705, 14, 204, "Text"],
Cell[3220, 100, 73, 1, 30, "Input"],
Cell[3296, 103, 280, 6, 71, "Text"],
Cell[3579, 111, 70, 1, 30, "Input"],
Cell[3652, 114, 361, 7, 90, "Text"],
Cell[4016, 123, 575, 10, 210, "Input"],
Cell[4594, 135, 115, 3, 33, "Text"],
Cell[4712, 140, 236, 5, 90, "Input"],
Cell[4951, 147, 915, 27, 72, "Text"],

Cell[CellGroupData[{
Cell[5891, 178, 53, 1, 30, "Input"],
Cell[5947, 181, 54, 1, 29, "Output"]
}, Open  ]],
Cell[6016, 185, 234, 6, 33, "Text"],

Cell[CellGroupData[{
Cell[6275, 195, 61, 1, 30, "Input"],
Cell[6339, 198, 39, 1, 29, "Output"]
}, Open  ]],
Cell[6393, 202, 811, 19, 71, "Text"],
Cell[7207, 223, 46, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[7278, 228, 77, 1, 30, "Input"],
Cell[7358, 231, 198, 3, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7593, 239, 107, 2, 30, "Input"],
Cell[7703, 243, 101, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7841, 250, 77, 1, 30, "Input"],
Cell[7921, 253, 198, 3, 48, "Output"]
}, Open  ]],
Cell[8134, 259, 247, 6, 33, "Text"],
Cell[8384, 267, 69, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[8478, 272, 48, 1, 30, "Input"],
Cell[8529, 275, 37, 1, 29, "Output"]
}, Open  ]],
Cell[8581, 279, 509, 14, 53, "Text"],
Cell[9093, 295, 143, 3, 30, "Input"],
Cell[9239, 300, 106, 2, 33, "Text"],
Cell[9348, 304, 75, 1, 30, "Input"],
Cell[9426, 307, 187, 5, 33, "Text"],
Cell[9616, 314, 618, 11, 110, "Input"],
Cell[10237, 327, 1668, 43, 190, "Text"],

Cell[CellGroupData[{
Cell[11930, 374, 136, 2, 50, "Input"],
Cell[12069, 378, 43, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12149, 384, 134, 3, 50, "Input"],
Cell[12286, 389, 66, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12389, 395, 136, 2, 50, "Input"],
Cell[12528, 399, 84, 1, 29, "Output"]
}, Open  ]],
Cell[12627, 403, 369, 11, 34, "Text"],

Cell[CellGroupData[{
Cell[13021, 418, 107, 2, 30, "Input"],
Cell[13131, 422, 88, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13256, 428, 112, 2, 30, "Input"],
Cell[13371, 432, 35, 1, 29, "Output"]
}, Open  ]],
Cell[13421, 436, 420, 12, 53, "Text"],
Cell[13844, 450, 61, 1, 30, "Input"],
Cell[13908, 453, 91, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[14024, 458, 66, 1, 30, "Input"],
Cell[14093, 461, 429, 6, 67, "Output"]
}, Open  ]],
Cell[14537, 470, 244, 6, 33, "Text"],
Cell[14784, 478, 664, 13, 130, "Input"],
Cell[15451, 493, 500, 12, 53, "Text"],
Cell[15954, 507, 149, 3, 30, "Input"],
Cell[16106, 512, 424, 10, 52, "Text"],

Cell[CellGroupData[{
Cell[16555, 526, 59, 1, 30, "Input"],
Cell[16617, 529, 10569, 188, 237, "Output"]
}, Open  ]],
Cell[27201, 720, 215, 5, 33, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

